@@ -1,10 +1,10 @@
 from .decorators import DocInherit as method_doc_inherit  # noqa
 
 __title__ = "python-doc-inherit"
-__summary__ = "A decorator used to inherit method documentation from parent classes."
+__summary__ = "Utilities to inherit method documentation from parent classes."
 __uri__ = "https://github.com/kavdev/python-doc-inherit/"
 
-__version__ = "0.1.0"
+__version__ = "0.2.0"
 
 __author__ = "Alexander Kavanaugh"
 __email__ = "alex@kavdev.io"
